@@ -1,16 +1,13 @@
 import asyncio
-import logging
 
-from pymax import MaxClient, Message, SocketMaxClient
-from pymax.files import Photo
+from pymax import MaxClient, Message
 from pymax.filters import Filter
-from pymax.static import AttachType
+from pymax.static.enum import AttachType
 
 phone = "+1234567890"
 
 
 client = MaxClient(phone=phone, work_dir="cache")
-# client = SocketMaxClient(phone=phone, work_dir="cache")
 
 
 @client.on_message(filter=Filter(chat_id=0))
@@ -31,6 +28,13 @@ async def handle_deleted_message(message: Message) -> None:
 @client.on_start
 async def handle_start() -> None:
     print("Client started successfully!")
+    history = await client.fetch_history(chat_id=0)
+    if history:
+        for message in history:
+            if message.attaches:
+                for attach in message.attaches:
+                    if attach.type == AttachType.STICKER:
+                        print(attach.lottie_url)
     # chat = await client.rework_invite_link(chat_id=0)
     # print(chat.link)
     # text = """
