@@ -13,13 +13,16 @@ from pymax.payloads import (
     RemoveUsersPayload,
     ReworkInviteLinkPayload,
 )
-from pymax.static import Opcode
+from pymax.static.enum import Opcode
 from pymax.types import Chat, Message
 
 
 class GroupMixin(ClientProtocol):
     async def create_group(
-        self, name: str, participant_ids: list[int] | None = None, notify: bool = True
+        self,
+        name: str,
+        participant_ids: list[int] | None = None,
+        notify: bool = True,
     ) -> tuple[Chat, Message] | None:
         """
         Создает группу
@@ -40,14 +43,18 @@ class GroupMixin(ClientProtocol):
                         CreateGroupAttach(
                             _type="CONTROL",
                             title=name,
-                            user_ids=participant_ids if participant_ids else [],
+                            user_ids=(
+                                participant_ids if participant_ids else []
+                            ),
                         )
                     ],
                 ),
                 notify=notify,
             ).model_dump(by_alias=True)
 
-            data = await self._send_and_wait(opcode=Opcode.MSG_SEND, payload=payload)
+            data = await self._send_and_wait(
+                opcode=Opcode.MSG_SEND, payload=payload
+            )
             if error := data.get("payload", {}).get("error"):
                 self.logger.error("Create group error: %s", error)
                 return None
@@ -67,6 +74,7 @@ class GroupMixin(ClientProtocol):
 
         except Exception:
             self.logger.exception("Create group failed")
+            return None
 
     async def invite_users_to_group(
         self,
@@ -172,7 +180,9 @@ class GroupMixin(ClientProtocol):
                 ),
             ).model_dump(by_alias=True, exclude_none=True)
 
-            data = await self._send_and_wait(opcode=Opcode.CHAT_UPDATE, payload=payload)
+            data = await self._send_and_wait(
+                opcode=Opcode.CHAT_UPDATE, payload=payload
+            )
 
             if error := data.get("payload", {}).get("error"):
                 self.logger.error("Change group settings error: %s", error)
@@ -203,7 +213,9 @@ class GroupMixin(ClientProtocol):
                 description=description,
             ).model_dump(by_alias=True, exclude_none=True)
 
-            data = await self._send_and_wait(opcode=Opcode.CHAT_UPDATE, payload=payload)
+            data = await self._send_and_wait(
+                opcode=Opcode.CHAT_UPDATE, payload=payload
+            )
 
             if error := data.get("payload", {}).get("error"):
                 self.logger.error("Change group profile error: %s", error)
@@ -241,9 +253,13 @@ class GroupMixin(ClientProtocol):
                 self.logger.error("Invalid group link: %s", link)
                 return None
 
-            payload = JoinGroupPayload(link=proceed_link).model_dump(by_alias=True)
+            payload = JoinGroupPayload(link=proceed_link).model_dump(
+                by_alias=True
+            )
 
-            data = await self._send_and_wait(opcode=Opcode.CHAT_JOIN, payload=payload)
+            data = await self._send_and_wait(
+                opcode=Opcode.CHAT_JOIN, payload=payload
+            )
 
             if error := data.get("payload", {}).get("error"):
                 self.logger.error("Join group error: %s", error)
@@ -275,9 +291,13 @@ class GroupMixin(ClientProtocol):
             str | None: Новая ссылка или None при ошибке.
         """
         try:
-            payload = ReworkInviteLinkPayload(chat_id=chat_id).model_dump(by_alias=True)
+            payload = ReworkInviteLinkPayload(chat_id=chat_id).model_dump(
+                by_alias=True
+            )
 
-            data = await self._send_and_wait(opcode=Opcode.CHAT_UPDATE, payload=payload)
+            data = await self._send_and_wait(
+                opcode=Opcode.CHAT_UPDATE, payload=payload
+            )
 
             if error := data.get("payload", {}).get("error"):
                 self.logger.error("Rework invite link error: %s", error)
